#!/usr/bin/env python

import json
import urllib
import sys
import re
import os

from optparse import OptionParser
from pykml import parser
from uuid import uuid4
#from commander import Commander

p = OptionParser(usage="kml2inst.py [options] file/url")
p.add_option("-i", "--dbid", dest="dbid", default=9999, help="DBID to use (default 9999)")
p.add_option("-f", "--field", dest="field", default=list(), action="append", help="Custom field (ex Orientation=90)")
p.add_option("-o", "--output", dest="output", default=".", help="Output directory")
#p.add_option("-d", "--dbsearch", dest="dbsearch", action="store_true", default=False, help="Attempt DB search to match units")

(options, args) = p.parse_args(args=None, values=None)

fields = dict() 
#cmd = Commander()

for f in options.field:
    s = f.split("=")
    fields[s[0]] = s[1]

def noslash(string):
    return re.sub(r'[&\/]', ' ', string)

def get_folder(folder, basedir=".", country=None):
    if country is None:
        country = cmd.country(folder.name.text)
        if country is not None: country = country[0]
   
    try:
        inner = len(folder.Folder)
        basedir = "%s/%s" % (basedir, noslash(folder.name.text))
        os.mkdir(basedir)

        for i in xrange(inner):
            get_folder(folder.Folder[i], basedir=basedir, country=country)
    except (AttributeError, OSError):
        pass

    try:
        f = {
            "DB_ID": 1,
            "FormatVersion": 0,
            "ValidFrom": fields['ValidFrom'] if 'ValidFrom' in fields else "" ,
            "ValidUntil": fields['ValilUntil'] if 'ValidUntil' in fields else "",
            "Name": folder.name.text,
            "Comments": fields['Comments'] if 'Comments' in fields else "credits to blh42",
            "MemberRecords": []
        }

        for p in folder.Placemark:
            '''
            if "Empty" not in p.name.text:
                if p.name.text.lower() == "ew site":
                    dbid = 937
                elif re.findall(r'(training|test)', p.name.text, flags=re.I):
                    continue
                else:
                    if options.dbsearch:
                        dbid = cmd.search(p.name.text, operator=country)
                        if dbid is None:
                            print country, p.name.text
                            continue
                    else:
                        dbid = options.dbid
            '''
            place = {
                "Member_DBID": int(options.dbid),
                "Member_GUID": str(uuid4()),
                "MemberType": None,
                "MemberName": p.name.text,
                "ParentGroupName": None,
                "Longitude": float(p.Point.coordinates.text.split(",")[0]),
                "Latitude": float(p.Point.coordinates.text.split(",")[1]),
                "LoadoutID": fields['LoadoutID'] if 'LoadoutID' in fields else 0,
                "Orientation": fields['Orientation'] if 'Orientation' in fields else 0.0,
                "HostedAircraftRecords": []
            }

            f['MemberRecords'].append(place)
    except AttributeError:
        return

    with open("%s/%s.inst" % (basedir, noslash(folder.name.text)), "wb") as fp:
        fp.write(json.dumps(f, indent=2))
        fp.close()

        print "Wrote %s/%s.inst" % (basedir, noslash(folder.name.text))

def main():
    print "kml2inst v0.2 by blh42"

    if len(args) < 1:
        p.print_help()
        sys.exit(127)

    resp = urllib.urlopen(args[0])

    k = parser.fromstring(resp.read())

    for i in xrange(len(k.Document.Folder)):
        get_folder(k.Document.Folder[i])

if __name__ == '__main__':
    main()
